==> knative-model-4.9.0-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubscriptionStatusFluent<A extends SubscriptionStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index);
    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    
/**
 * This method has been deprecated, please use method buildPhysicalSubscription instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public SubscriptionStatusPhysicalSubscription getPhysicalSubscription();
    public SubscriptionStatusPhysicalSubscription buildPhysicalSubscription();
    public A withPhysicalSubscription(SubscriptionStatusPhysicalSubscription physicalSubscription);
    public Boolean hasPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item);
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item);

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SubscriptionStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface PhysicalSubscriptionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionStatusPhysicalSubscriptionFluent<SubscriptionStatusFluent.PhysicalSubscriptionNested<N>>{

        
    public N and();    public N endPhysicalSubscription();
}


}

==> knative-model-4.9.1-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubscriptionStatusFluent<A extends SubscriptionStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public SubscriptionStatusFluent.ConditionsNested<A> editCondition(int index);
    public SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
    public SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    
/**
 * This method has been deprecated, please use method buildPhysicalSubscription instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public SubscriptionStatusPhysicalSubscription getPhysicalSubscription();
    public SubscriptionStatusPhysicalSubscription buildPhysicalSubscription();
    public A withPhysicalSubscription(SubscriptionStatusPhysicalSubscription physicalSubscription);
    public Boolean hasPhysicalSubscription();
    public A withNewPhysicalSubscription(String deadLetterSinkURI,String replyURI,String subscriberURI);
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> withNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item);
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscription();
    public SubscriptionStatusFluent.PhysicalSubscriptionNested<A> editOrNewPhysicalSubscriptionLike(SubscriptionStatusPhysicalSubscription item);

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SubscriptionStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface PhysicalSubscriptionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriptionStatusPhysicalSubscriptionFluent<SubscriptionStatusFluent.PhysicalSubscriptionNested<N>>{

        
    public N and();    public N endPhysicalSubscription();
}


}
